@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Net::SAML2::Protocol::Assertion;
-our $VERSION = '0.54'; # TRIAL VERSION
+our $VERSION = '0.56'; # TRIAL VERSION
 
 use Moose;
 use MooseX::Types::DateTime qw/ DateTime /;
@@ -57,12 +57,15 @@ sub new_from_xml {
         $xpath      = XML::LibXML::XPathContext->new($dom);
         $xpath->registerNs('saml',  'urn:oasis:names:tc:SAML:2.0:assertion');
         $xpath->registerNs('samlp', 'urn:oasis:names:tc:SAML:2.0:protocol');
+        $xpath->registerNs('dsig', 'http://www.w3.org/2000/09/xmldsig#');
         $xpath->registerNs('xenc', 'http://www.w3.org/2001/04/xmlenc#');
 
         my $xml_opts->{ no_xml_declaration } = 1;
 
         my $assert = $xpath->findnodes('//saml:Assertion')->[0];
-        if (defined $assert) {
+        my @signedinfo = $xpath->findnodes('dsig:Signature', $assert);
+
+        if (defined $assert && (scalar @signedinfo ne 0)) {
             my $x   = Net::SAML2::XML::Sig->new($xml_opts);
             my $ret = $x->verify($assert->serialize);
             die "Decrypted Assertion signature check failed" unless $ret;
@@ -163,7 +166,7 @@ Net::SAML2::Protocol::Assertion - Net::SAML2::Protocol::Assertion - SAML2 assert
 
 =head1 VERSION
 
-version 0.54
+version 0.56
 
 =head1 SYNOPSIS
 
